@@ -8,6 +8,13 @@ from pylint.interfaces import IAstroidChecker
 from .transform import transform_module, is_some_protobuf_module, to_pytype, is_composite, is_repeated, is_oneof
 from .transform import SimpleDescriptor, PROTOBUF_IMPLICIT_ATTRS, PROTOBUF_ENUM_IMPLICIT_ATTRS
 
+try:
+    from astroid import Index as IndexNode
+except ImportError:
+    # Compatibility shim for astroid >= 2.6
+    class IndexNode(object):
+        pass
+
 _MISSING_IMPORT_IS_ERROR = False
 BASE_ID = 59
 MESSAGES = {
@@ -110,7 +117,9 @@ def _scalar_typecheck(val, val_type):
     elif val_type is bool:
         return check(val, (float, int, bool))
     elif val_type is str:
-        return check(val, str)
+        return check(val, (str, bytes))
+    elif val_type is bytes:
+        return check(val, bytes)
     else:
         return True  # Are there any other scalar protobuf types?
 
@@ -222,7 +231,11 @@ class ProtobufDescriptorChecker(BaseChecker):
         keywords = node.keywords or []
         for kw in keywords:
             arg_name, val_node = kw.arg, kw.value
-            if arg_name not in desc.fields_by_name:
+            if arg_name is None:
+                # If arg_name is None then we are dealing with **kwargs, in which case we don't
+                # really care what arguments are being passed, just ignore them to be safe.
+                continue
+            elif arg_name not in desc.fields_by_name:
                 # This is probably too fragile (should it be replaced by a separate message?)
                 # Also, it's probably not fair to always refer to this as a constructor call, though arguably
                 # .add() on repeated composite fields is "constructing" the sub-message
@@ -470,13 +483,17 @@ class ProtobufDescriptorChecker(BaseChecker):
         attr, slice = node.value, node.slice
         if not isinstance(attr, astroid.Attribute) or attr.attrname != 'Extensions':
             return
-        if not isinstance(slice, astroid.Index) or not isinstance(slice.value, astroid.Attribute):
+        if isinstance(slice, IndexNode):  # astroid < 2.6
+            value = slice.value
+        else:
+            value = slice
+        if not isinstance(value, astroid.Attribute):
             return
         target_desc = _get_protobuf_descriptor(attr.expr)
-        ext_desc = _get_protobuf_descriptor(slice.value.expr)
+        ext_desc = _get_protobuf_descriptor(value.expr)
         if target_desc is None:
             return
-        ext_name = slice.value.attrname
+        ext_name = value.attrname
         if ext_desc is not None:
             if ext_name not in ext_desc.extensions_by_name:
                 return  # should raise protobuf-undefined-attribute elsewhere
